* { box-sizing: border-box; }
body {
    font-family: "Segoe UI", system-ui, -apple-system, sans-serif;
    margin: 0;
    min-height: 100vh;
    background: linear-gradient(145deg, #1a1a2e 0%, #16213e 50%, #0f3460 100%);
    color: #e8e8e8;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    padding: 1rem;
    overflow-x: hidden;
    gap: 1.25rem;
}
/* Must match home.css nav rules — without these, inline SVGs render at huge default size. */
.site-nav {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    align-items: center;
    gap: 1rem;
    padding: 0.75rem clamp(1rem, 4vw, 2rem);
    margin-top: 0;
    margin-bottom: 0;
    border-bottom: 1px solid rgba(255, 255, 255, 0.15);
    width: 100%;
    max-width: 640px;
    flex-shrink: 0;
}
.site-nav a {
    color: #e8e8e8;
    text-decoration: none;
    font-weight: 600;
    font-size: clamp(0.875rem, 2.5vw, 1rem);
}
.site-nav a:hover { color: #7dd3fc; }
.site-nav a.active { color: #7dd3fc; }
.site-nav a { display: inline-flex; align-items: center; gap: 0.4rem; }
.site-nav .nav-icon { width: 1.1rem; height: 1.1rem; flex-shrink: 0; }
.site-nav .nav-logo-link { margin-right: 0.25rem; }
.site-nav .nav-logo { height: 2rem; width: auto; display: block; max-height: 2rem; }
.pin-wrap {
    max-width: 320px;
    width: 100%;
    background: rgba(255, 255, 255, 0.06);
    border: 1px solid rgba(255, 255, 255, 0.12);
    border-radius: 16px;
    padding: 1.5rem;
    box-shadow: 0 20px 50px rgba(0, 0, 0, 0.3);
}
.pin-wrap h1 { margin: 0 0 1rem 0; font-size: 1.15rem; color: #fff; }
.pin-wrap p { margin: 0 0 1rem 0; opacity: 0.9; font-size: 0.95rem; }
.pin-error { color: #fca5a5; margin-bottom: 0.75rem !important; }
.pin-wrap input[type="password"] {
    width: 100%;
    padding: 0.75rem 1rem;
    border: 1px solid rgba(255, 255, 255, 0.2);
    border-radius: 10px;
    background: rgba(0, 0, 0, 0.2);
    color: #e8e8e8;
    font-size: 1rem;
    margin-bottom: 1rem;
}
.pin-wrap input:focus { outline: none; border-color: #7dd3fc; }
.pin-wrap button {
    width: 100%;
    padding: 0.75rem;
    border-radius: 10px;
    border: none;
    background: #7dd3fc;
    color: #1a1a2e;
    font-weight: 600;
    font-size: 1rem;
    cursor: pointer;
}
.pin-wrap button:hover { background: #38bdf8; }
.pin-wrap a { color: #7dd3fc; text-decoration: none; font-size: 0.9rem; }
.pin-wrap a:hover { text-decoration: underline; }

.pin-modal-overlay {
    display: none;
    position: fixed;
    inset: 0;
    background: rgba(0, 0, 0, 0.65);
    align-items: center;
    justify-content: center;
    z-index: 1000;
    padding: 1rem;
}
.pin-modal-overlay.is-open { display: flex; }
.pin-modal-card {
    max-width: 420px;
    width: 100%;
    background: linear-gradient(145deg, #1a1a2e 0%, #16213e 100%);
    border: 1px solid rgba(255, 255, 255, 0.12);
    border-radius: 14px;
    padding: 1.2rem;
    box-shadow: 0 20px 45px rgba(0, 0, 0, 0.45);
}
.pin-modal-card h2 {
    margin: 0 0 0.7rem 0;
    font-size: 1.1rem;
    color: #fff;
}
.pin-modal-card p {
    margin: 0;
    font-size: 0.95rem;
    line-height: 1.5;
    opacity: 0.95;
}
.pin-modal-actions {
    margin-top: 1rem;
    display: flex;
    justify-content: flex-end;
    gap: 0.6rem;
}
.pin-modal-btn {
    border: 1px solid transparent;
    border-radius: 9px;
    padding: 0.5rem 0.9rem;
    font-size: 0.92rem;
    font-weight: 600;
    cursor: pointer;
}
.pin-modal-btn-cancel {
    background: rgba(255, 255, 255, 0.1);
    border-color: rgba(255, 255, 255, 0.2);
    color: #e8e8e8;
}
.pin-modal-btn-danger {
    background: rgba(239, 68, 68, 0.25);
    border-color: rgba(239, 68, 68, 0.55);
    color: #fecaca;
}
